@@ -21,7 +21,7 @@
  *  along with this program ; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  *
- *  $Id: motion.h,v 1.24.2.1 2009/05/25 09:03:47 Isibaar Exp $
+ *  $Id: motion.h,v 1.27.2.1 2010/12/28 19:19:57 Isibaar Exp $
  *
  ***************************************************************************/
 
@@ -54,7 +54,8 @@ void MotionEstimation(MBParam * const pParam,
 					const IMAGE * const pRefV,
 					const IMAGE * const pRefHV,
 					const IMAGE * const pGMC,
-					const uint32_t iLimit);
+					const uint32_t iLimit,
+					const int num_slices);
 
 void
 MotionEstimationBVOP(MBParam * const pParam,
@@ -70,7 +71,8 @@ MotionEstimationBVOP(MBParam * const pParam,
 						const IMAGE * const b_ref,
 						const IMAGE * const b_refH,
 						const IMAGE * const b_refV,
-						const IMAGE * const b_refHV);
+						const IMAGE * const b_refHV,
+						const int num_slices);
 
 void
 GMEanalysis(const MBParam * const pParam,
@@ -78,7 +80,8 @@ GMEanalysis(const MBParam * const pParam,
 			const FRAMEINFO * const reference,
 			const IMAGE * const pRefH,
 			const IMAGE * const pRefV,
-			const IMAGE * const pRefHV);
+			const IMAGE * const pRefHV,
+			const int num_slices);
 
 WARPPOINTS
 GlobalMotionEst(MACROBLOCK * const pMBs,
@@ -87,7 +90,8 @@ GlobalMotionEst(MACROBLOCK * const pMBs,
 				const FRAMEINFO * const reference,
 				const IMAGE * const pRefH,
 				const IMAGE * const pRefV,
-				const IMAGE * const pRefHV);
+				const IMAGE * const pRefHV,
+				const int num_slices);
 
 int
 GlobalMotionEstRefine(
@@ -139,7 +143,8 @@ MBMotionCompensation(MACROBLOCK * const mb,
 					const uint32_t height,
 					const uint32_t edged_width,
 					const int32_t quarterpel,
-					const int32_t rounding);
+					const int32_t rounding,
+					uint8_t * const tmp);
 
 void
 MBMotionCompensationBVOP(MBParam * pParam,
@@ -155,6 +160,7 @@ MBMotionCompensationBVOP(MBParam * pParam,
 							const IMAGE * const b_refh,
 							const IMAGE * const b_refv,
 							const IMAGE * const b_refhv,
-							int16_t * dct_codes);
+							int16_t * dct_codes,
+							uint8_t * const tmp);
 
 #endif							/* _MOTION_H_ */
